@@ -1,14 +1,14 @@
-import * as fs from 'fs';
 import * as path from 'path';
 import { Cdk8sTeamJsiiProject } from '@cdk8s/projen-common';
+import { github, javascript } from 'projen';
 import { generateApiResources } from './projenrc/gen-api-resource';
 
-// the version of k8s this branch supports
-const SPEC_VERSION = fs.readFileSync('projenrc/latest-k8s-version.txt', 'utf-8');
-const K8S_VERSION = `1.${SPEC_VERSION}.0`;
-
 // the latest version of k8s we support
-const LATEST_SUPPORTED_K8S_VERSION = Number(SPEC_VERSION);
+const LATEST_SUPPORTED_K8S_VERSION = 26;
+
+// the version of k8s this branch supports
+const SPEC_VERSION = '26';
+const K8S_VERSION = `1.${SPEC_VERSION}.0`;
 
 const project = new Cdk8sTeamJsiiProject({
   name: `cdk8s-plus-${SPEC_VERSION}`,
@@ -26,6 +26,8 @@ const project = new Cdk8sTeamJsiiProject({
     'microservices',
   ],
 
+  projenCredentials: github.GithubCredentials.fromPersonalAccessToken(),
+
   peerDeps: [
     'cdk8s',
     'constructs',
@@ -60,6 +62,11 @@ const project = new Cdk8sTeamJsiiProject({
         `k8s-${LATEST_SUPPORTED_K8S_VERSION - 1}/main`,
         `k8s-${LATEST_SUPPORTED_K8S_VERSION - 2}/main`,
       ],
+
+      // run upgrade-dependencies workflow at a different hour than other cdk8s
+      // repos to decrease flakiness of integration tests caused by new versions
+      // of cdk8s being published to different languages at the same time
+      schedule: javascript.UpgradeDependenciesSchedule.expressions(['0 2 * * *']),
     },
   },
   backport: true,
@@ -97,8 +104,4 @@ project.addTask('regenerate-api-information', {
 });
 generateApiResources(project, 'api-resources.txt', 'src/api-resource.generated.ts');
 
-// Projen task to update references to old versions of cdk8s-plus
-const versionTaskObject = project.addTask('update-k8s-version-references');
-versionTaskObject.exec('ts-node projenrc/replace-version-references.ts ' + SPEC_VERSION);
-
 project.synth();
\ No newline at end of file
